@@ -26,12 +26,23 @@ def monitor_log(log_name):
 ###############################################################################
 #>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
 
+BASELINE = ["-v", "--exclude=test_performance"]
+PERFORMANCE = ["--tests=test_performance"]
+PROFILING = [
+    "--with-profile",
+    "--profile-stats-file=stockpyle.prof"
+    ]
 COVERAGE = [
     '--with-coverage',
     '--cover-package=stockpyle',
+    '--cover-erase',
     ]
 
-FLAGS = ["-v"] + COVERAGE# + ["--tests=test_sqlalchemy_store"]
+FLAGS = BASELINE + COVERAGE
+
+# monitor_log("sqlalchemy.engine")
+# monitor_log("sqlalchemy.pool")
+# monitor_log("sqlalchemy.orm")    
 
 #<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 ###############################################################################
@@ -44,4 +55,5 @@ if __name__ == "__main__":
     sys.path.insert(0, os.path.join(os.path.dirname(__file__), ".."))
 
     # run nosetests
-    nose.core.TestProgram(defaultTest="tests", argv=sys.argv+FLAGS)
\ No newline at end of file
+    nose.core.TestProgram(defaultTest="tests", argv=sys.argv+FLAGS)
+    
\ No newline at end of file
